Haystack integration for email via JMAP.
Implements HaystackProvider over a JMAP mail server, allowing email
messages and threads to be searched as Terraphim haystack documents.
Structs
- Body
Part - Represents an email body part.
- Body
Value - Represents the value of an email body part.
- Represents an email.
- Email
Address - Represents an email address.
- JMAP
Client - A client for interacting with a JMAP server.
- Session
- Represents a JMAP session.
Functions
- email_
to_ document - Converts an Email into a Document with enriched metadata.